@@ -1,15 +1,17 @@
 package POE::Component::WakeOnLAN;
+{
+  $POE::Component::WakeOnLAN::VERSION = '1.04';
+}
+
+#ABSTRACT: A POE Component to send packets to power on computers.
 
 use strict;
 use warnings;
 use Socket;
 use Carp;
 use IO::Socket::INET;
-use Net::IP;
+use Net::IP::Minimal;
 use POE;
-use vars qw($VERSION);
-
-$VERSION = '1.02';
 
 sub wake_up {
   my $package = shift;
@@ -19,7 +21,7 @@ sub wake_up {
   croak "$package wake_up requires an 'event' parameter\n" unless $params{event};
   $params{macaddr} =~ s/://g;
   $params{port} = 9 unless $params{port} and $params{port} =~ /^\d+$/;
-  $params{address} = '255.255.255.255' unless $params{address} and Net::IP::ip_get_version( $params{address} );
+  $params{address} = '255.255.255.255' unless $params{address} and Net::IP::Minimal::ip_get_version( $params{address} );
   my $options = delete $params{options};
   my $self = bless \%params, $package;
   $self->{session_id} = POE::Session->create(
@@ -77,12 +79,19 @@ sub _ready {
 }
 
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 POE::Component::WakeOnLAN - A POE Component to send packets to power on computers.
 
+=head1 VERSION
+
+version 1.04
+
 =head1 SYNOPSIS
 
   use strict;
@@ -90,27 +99,27 @@ POE::Component::WakeOnLAN - A POE Component to send packets to power on computer
   use Data::Dumper;
   use POE;
   use POE::Component::WakeOnLAN;
-  
+
   my $mac_address = '00:0a:e4:4b:b0:94';
-  
+
   POE::Session->create(
      package_states => [
   	'main' => [qw(_start _response)],
      ],
   );
-  
-  
+
+
   $poe_kernel->run();
   exit 0;
-  
+
   sub _start {
-    POE::Component::WakeOnLAN->wake_up( 
+    POE::Component::WakeOnLAN->wake_up(
   	macaddr => $mac_address,
   	event   => '_response',
     );
     return;
   }
-  
+
   sub _response {
     print Dumper( $_[ARG0] );
     return;
@@ -118,7 +127,7 @@ POE::Component::WakeOnLAN - A POE Component to send packets to power on computer
 
 =head1 DESCRIPTION
 
-POE::Component::WakeOnLAN is a L<POE> component that sends wake-on-lan (AKA magic) 
+POE::Component::WakeOnLAN is a L<POE> component that sends wake-on-lan (AKA magic)
 packets to turn on machines that are wake-on-lan capable.
 
 It is based on the L<Net::Wake> module by Clinton Wong.
@@ -138,11 +147,11 @@ Sends a wake-on-lan packet via UDP. Takes a number of parameters:
   'session', optional if the poco is spawned from within another session;
   'options', a hashref of POE Session options to pass to the component;
 
-Generally speaking, you should use a broadcast address for C<address> ( the component defaults 
-to using C<255.255.255.255> if one is not supplied ), Using the host's last known IP address 
+Generally speaking, you should use a broadcast address for C<address> ( the component defaults
+to using C<255.255.255.255> if one is not supplied ), Using the host's last known IP address
 is usually not sufficient since the IP address may no longer be in the ARP cache.
 
-If you wish to send a magic packet to a remote subnet, you can use a variation of '192.168.0.255', 
+If you wish to send a magic packet to a remote subnet, you can use a variation of '192.168.0.255',
 given that you know the subnet mask to generate the proper broadcast address.
 
 The C<session> parameter is only required if you wish the output event to go to a different
@@ -166,18 +175,6 @@ This is generated by the poco. ARG0 will be a hash reference with the following
 
 Plus an arbitary key/values that were passed.
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
-
-Clinton Wong
-
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and Clinton Wong.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<POE>
@@ -186,4 +183,16 @@ L<Net::Wake>
 
 L<http://gsd.di.uminho.pt/jpo/software/wakeonlan/mini-howto/>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Chris Williams and Clinton Wong.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
